@@ -1,9 +1,18 @@
 from django.db import models
 
 from .fields import (
-    ArrayField, BigIntegerRangeField, CICharField, CIEmailField, CITextField,
-    DateRangeField, DateTimeRangeField, DecimalRangeField, EnumField,
-    HStoreField, IntegerRangeField, SearchVectorField,
+    ArrayField,
+    BigIntegerRangeField,
+    CICharField,
+    CIEmailField,
+    CITextField,
+    DateRangeField,
+    DateTimeRangeField,
+    DecimalRangeField,
+    EnumField,
+    HStoreField,
+    IntegerRangeField,
+    SearchVectorField,
 )
 
 
@@ -16,7 +25,6 @@ class Tag:
 
 
 class TagField(models.SmallIntegerField):
-
     def from_db_value(self, value, expression, connection):
         if value is None:
             return value
@@ -36,7 +44,7 @@ class TagField(models.SmallIntegerField):
 class PostgreSQLModel(models.Model):
     class Meta:
         abstract = True
-        required_db_vendor = 'postgresql'
+        required_db_vendor = "postgresql"
 
 
 class IntegerArrayModel(PostgreSQLModel):
@@ -66,7 +74,9 @@ class NestedIntegerArrayModel(PostgreSQLModel):
 class OtherTypesArrayModel(PostgreSQLModel):
     ips = ArrayField(models.GenericIPAddressField(), default=list)
     uuids = ArrayField(models.UUIDField(), default=list)
-    decimals = ArrayField(models.DecimalField(max_digits=5, decimal_places=2), default=list)
+    decimals = ArrayField(
+        models.DecimalField(max_digits=5, decimal_places=2), default=list
+    )
     tags = ArrayField(TagField(), blank=True, null=True)
     json = ArrayField(models.JSONField(default=dict), default=list)
     int_ranges = ArrayField(IntegerRangeField(), blank=True, null=True)
@@ -117,15 +127,15 @@ class CITestModel(PostgreSQLModel):
 
 
 class Line(PostgreSQLModel):
-    scene = models.ForeignKey('Scene', models.CASCADE)
-    character = models.ForeignKey('Character', models.CASCADE)
+    scene = models.ForeignKey("Scene", models.CASCADE)
+    character = models.ForeignKey("Character", models.CASCADE)
     dialogue = models.TextField(blank=True, null=True)
     dialogue_search_vector = SearchVectorField(blank=True, null=True)
     dialogue_config = models.CharField(max_length=100, blank=True, null=True)
 
 
 class LineSavedSearch(PostgreSQLModel):
-    line = models.ForeignKey('Line', models.CASCADE)
+    line = models.ForeignKey("Line", models.CASCADE)
     query = models.CharField(max_length=100)
 
 
@@ -147,7 +157,9 @@ class RangeLookupsModel(PostgreSQLModel):
     timestamp = models.DateTimeField(blank=True, null=True)
     date = models.DateField(blank=True, null=True)
     small_integer = models.SmallIntegerField(blank=True, null=True)
-    decimal_field = models.DecimalField(max_digits=5, decimal_places=2, blank=True, null=True)
+    decimal_field = models.DecimalField(
+        max_digits=5, decimal_places=2, blank=True, null=True
+    )
 
 
 class ArrayFieldSubclass(ArrayField):
@@ -159,6 +171,7 @@ class AggregateTestModel(PostgreSQLModel):
     """
     To test postgres-specific general aggregation functions
     """
+
     char_field = models.CharField(max_length=30, blank=True)
     integer_field = models.IntegerField(null=True)
     boolean_field = models.BooleanField(null=True)
@@ -169,6 +182,7 @@ class StatTestModel(PostgreSQLModel):
     """
     To test postgres-specific aggregation functions for statistics
     """
+
     int1 = models.IntegerField()
     int2 = models.IntegerField()
     related_field = models.ForeignKey(AggregateTestModel, models.SET_NULL, null=True)
@@ -187,7 +201,7 @@ class Room(models.Model):
 
 
 class HotelReservation(PostgreSQLModel):
-    room = models.ForeignKey('Room', on_delete=models.CASCADE)
+    room = models.ForeignKey("Room", on_delete=models.CASCADE)
     datespan = DateRangeField()
     start = models.DateTimeField()
     end = models.DateTimeField()
